require_dependency "nukleus/authenticated_controller"

module Nukleus
    class DocumentsController < AuthenticatedController
        before_action :set_document, only: [:show, :edit, :update, :destroy]

        def index
            @documents = Document.all
        end

        def show
        end

        def new
            @document = Document.new
        end

        def edit
        end

        def create
            @document = Document.new(document_params.to_h)
            respond_to do |format|
                if @document.save
                    format.json { render :show, status: :created }
                else
                    format.json { render json: @document.errors, status: :unprocessable_entity }
                end
            end
        end

        def update
            @document = @document.update_with_copy(document_params.to_h)
            if @document.errors.messages.keys.count == 0
                render :show, status: :ok
            else
                render json: @document.errors, status: :unprocessable_entity
            end
        end

        def destroy
            @document.destroy
            head :no_content
        end

        private

        def set_document
            Document.prepend(Nukleus::Versioning) # Activate Versioning features.
            @document = Document.where(document_id: params[:id]).first
        end

        def document_params
            params.require(:document).permit(:document_file, :document_id, :document_file_filename, meta_data: {}, tags: [])
        end
    end
end
